@@ -4,7 +4,6 @@ from pkg_resources import get_distribution
 __version__ = get_distribution("pyplatform-common").version
 
 
-
 def show_me(module=None, docstring=False):
     """Print functions contained in a module or script.
 
@@ -13,7 +12,7 @@ def show_me(module=None, docstring=False):
         doctring {bool} -- if true, prints doctring of functions as well (default=False)
 
     Example:
-    import pyplatform as pyp
+    import pyplatform.common as pyp
     pyp.show_me() # prints functions names contained in pyplatfrom
 
     from pyplatform import udf
