@@ -6,17 +6,18 @@ import requests
 import jwt
 import time
 
+
 def credhub_get_credentials(output_option='FILE'):
     """
     Return credhub managed credentials  in pivotal cloud  at runtime from `VCAP_SERVICES` environment variable.
 
     documentatioin: https://docs.pivotal.io/credhub-service-broker/using.html
-    
+
     Keyword Arguments:
         output_option {str} -- output format of credentials.
                 {'FILE':'downloads credential ``value`` as a temp file, sets credential ``key`` as variable pointing to temp file path'\
                 'DICT':'returns credential ``value`` as dict object'}. (default: {'FILE'})
-    
+
     Recommended credential keys for each platform:
         {'gpc':'GOOGLE_APPLICATION_CREDENTIALS' \
             ,'azure': 'AZURE_CREDENTIALS' \
@@ -88,24 +89,25 @@ def gcp_get_auth_header(scope='https://www.googleapis.com/auth/devstorage.read_o
     Returns:
         {str, requests.response, requests.response.json} -- AUTH_HEADER and TOKEN are str
     """
-    
+
     if not credentials_file_path:
-        logging.debug("credentials file not provided, using env variable GOOGLE_APPLICATION_CREDENTIALS")
-        credentials_file_path = os.environ.get('GOOGLE_APPLICATION_CREDENTIALS')
+        logging.debug(
+            "credentials file not provided, using env variable GOOGLE_APPLICATION_CREDENTIALS")
+        credentials_file_path = os.environ.get(
+            'GOOGLE_APPLICATION_CREDENTIALS')
         if not credentials_file_path:
             logging.error("Default credentials not set")
             credentials_file_path = 'no-cred'
-    
-        
+
     if os.path.isfile(credentials_file_path):
         with open(credentials_file_path) as file:
             credentials = json.loads(file.read())
-            
+
         client_secret = credentials['private_key']
         client_email = credentials['client_email']
-        token_uri  = credentials['token_uri'] #  "https://oauth2.googleapis.com/token"
-        
-        
+        # "https://oauth2.googleapis.com/token"
+        token_uri = credentials['token_uri']
+
         iat = time.time()
         exp = iat + 3600
         payload = {'iss': client_email,
@@ -116,13 +118,15 @@ def gcp_get_auth_header(scope='https://www.googleapis.com/auth/devstorage.read_o
                    'exp': exp}
         additional_headers = {'kid': client_secret}
         signed_jwt = jwt.encode(payload, client_secret, headers=additional_headers,
-                               algorithm='RS256')
-        if output_option=='JWT':
+                                algorithm='RS256')
+        if output_option == 'JWT':
             return signed_jwt
-        
+
         headers = {"Content-Type": "application/x-www-form-urlencoded"}
-        data= {"grant_type" : "urn:ietf:params:oauth:grant-type:jwt-bearer", "assertion":signed_jwt}
-        response = requests.request("POST",token_uri,headers=headers,data=data)
+        data = {"grant_type": "urn:ietf:params:oauth:grant-type:jwt-bearer",
+                "assertion": signed_jwt}
+        response = requests.request(
+            "POST", token_uri, headers=headers, data=data)
         if response.status_code == 200:
             access_token = response.json()['access_token']
             if output_option == 'TOKEN':
@@ -134,62 +138,15 @@ def gcp_get_auth_header(scope='https://www.googleapis.com/auth/devstorage.read_o
             else:
                 return f'Bearer {access_token}'
         else:
-            logging.error(f"access_token request unsuccessfull with status code {response.status_code}")
+            logging.error(
+                f"access_token request unsuccessfull with status code {response.status_code}")
             return response
-    
+
     else:
-        logging.error("credential file not provided nor env variable GOOGLE_APPLICATION_CREDENTIALS is set to cred path")
+        logging.error(
+            "credential file not provided nor env variable GOOGLE_APPLICATION_CREDENTIALS is set to cred path")
 
-def cf_get_auth_header(output_option='AUTH_HEADER', credentials_file_path=None):
-    """
-    Return OAuth2 Authorization header for Pivotal Cloud Foundary API calls.
 
-    Keyword Arguments:
-        output_option {str} -- output format of function (default: {'AUTH_HEADER'})
-            other options include {'TOKEN','RESPONSE','JSON'}
-        credentials_file_path {str} -- file path of credentails.json (default: {None})
-
-    Returns:
-        {str, requests.response, requests.response.json} -- AUTH_HEADER and TOKEN are str
-    """
-
-    if not credentials_file_path:
-        logging.debug("credentials file not provided, using default env variable PIVOTAL_CREDENTIALS")
-        credentials_file_path = os.environ.get('PIVOTAL_CREDENTIALS')
-        if not credentials_file_path:
-            logging.error("Default credentials not set")
-            credentials_file_path = 'no-cred'
-    
-    if os.path.isfile(credentials_file_path):
-        with open(credentials_file_path) as file:
-            credentials = json.loads(file.read())
-
-        headers = {"Content-Type": "application/json",
-        "Accept": "application/json;charset=UTF-8",
-            "Authorization": "Basic Y2Y6"}
-        username=credentials.get('username')
-        password=credentials.get('password')
-        token_url = credentials.get('token_url')
-        
-        logging.info(f"signing in {token_url} as {username}")
-        token_url = f'{token_url}?grant_type=password&username={username}&password={password}&response_type=token'
-        response = requests.get(token_url,verify=False,headers=headers)
-        logging.debug(f"response code: {response.status_code} from token request to {response.url}")
-        
-        if response.status_code == 200:
-            if output_option == 'RESPONSE':
-                return response
-            elif output_option == 'JSON':
-                return response.json()
-            elif output_option == 'TOKEN':
-                return response.json().get('access_token')
-            else:
-                return f"bearer {response.json().get('access_token')}"
-
-        else:
-            logging.error(f"access_token request unsuccessfull with status code {response.status_code}")
-            return response
-    
 def gcs_reader(gcs_uri, auth_header=None, output_option='TEXT'):
     """
     GET request to Google Cloud Storage api with core Python libraries.
@@ -207,29 +164,31 @@ def gcs_reader(gcs_uri, auth_header=None, output_option='TEXT'):
     """
     from urllib.parse import quote_plus
     if not auth_header:
-        auth_header = gcp_get_auth_header() #dependency
-        
+        auth_header = gcp_get_auth_header()  # dependency
+
     bucket = gcs_uri[5:].split('/')[0]
     blob = quote_plus('/'.join(gcs_uri[5:].split('/')[1:]))
-    
+
     url = f'https://storage.googleapis.com/storage/v1/b/{bucket}/o/{blob}'
-    
+
     headers = {
         'Authorization': auth_header,
         'content-type': 'application/json'
     }
-    response = requests.get(url, headers=headers,params={'alt':'media'})
-    logging.debug(f"response code from {response.url} is {response.status_code}")
-    
-    if output_option=='RESPONSE':
+    response = requests.get(url, headers=headers, params={'alt': 'media'})
+    logging.debug(
+        f"response code from {response.url} is {response.status_code}")
+
+    if output_option == 'RESPONSE':
         return response
-    elif output_option=='CONTENT':
+    elif output_option == 'CONTENT':
         return response.content
-    elif output_option=='JSON':
+    elif output_option == 'JSON':
         return response.json()
     else:
         return response.text
 
+
 def make_requirements_txt(project_dir='.'):
     """Make requirements.txt file from main.py or module folder.
 
@@ -242,4 +201,4 @@ def make_requirements_txt(project_dir='.'):
     else:
         project_dir = os.path.dirname(project_dir)
 #         os.chdir(script_path)
-    return os.system(f"pipreqs {project_dir}")
\ No newline at end of file
+    return os.system(f"pipreqs {project_dir}")
